import { Span as SpanInterface, SpanContext } from '@sentry/types';
export declare const TRACEPARENT_REGEXP: RegExp;
/**
 * Span contains all data about a span
 */
export declare class Span implements SpanInterface, SpanContext {
    /**
     * @inheritDoc
     */
    private readonly _traceId;
    /**
     * @inheritDoc
     */
    private readonly _spanId;
    /**
     * @inheritDoc
     */
    private readonly _parentSpanId?;
    /**
     * @inheritDoc
     */
    readonly sampled?: boolean;
    /**
     * Timestamp when the span was created.
     */
    readonly startTimestamp: number;
    /**
     * Finish timestamp of the span.
     */
    timestamp?: number;
    /**
     * @inheritDoc
     */
    transaction?: string;
    /**
     * @inheritDoc
     */
    op?: string;
    /**
     * @inheritDoc
     */
    description?: string;
    /**
     * @inheritDoc
     */
    tags?: {
        [key: string]: string;
    };
    /**
     * @inheritDoc
     */
    data?: {
        [key: string]: any;
    };
    /**
     * List of spans that were finalized
     */
    finishedSpans: Span[];
    constructor(spanContext?: SpanContext);
    /**
     * Creates a new `Span` while setting the current `Span.id` as `parentSpanId`.
     * Also the `sampled` decision will be inherited.
     */
    newSpan(spanContext?: Pick<SpanContext, Exclude<keyof SpanContext, 'spanId'>>): Span;
    /**
     * Continues a trace from a string (usually the header).
     * @param traceparent Traceparent string
     */
    static fromTraceparent(traceparent: string, spanContext?: Pick<SpanContext, Exclude<keyof SpanContext, 'spanId' | 'sampled' | 'traceid'>>): Span | undefined;
    /**
     * Sets the finish timestamp on the current span
     */
    finish(): void;
    /**
     * @inheritDoc
     */
    toTraceparent(): string;
    /**
     * @inheritDoc
     */
    getTraceContext(): object;
    /**
     * @inheritDoc
     */
    toJSON(): object;
}
//# sourceMappingURL=span.d.ts.map